--- a/model/releases/CR-prov-constraints-20121211/Overview.html Fri Dec 07 14:16:58 2012 +0000
+++ b/model/releases/CR-prov-constraints-20121211/Overview.html Fri Dec 07 16:58:35 2012 +0000
@@ -688,7 +688,7 @@
<dt>Previous version:</dt>
- <dd><a href="http://www.w3.org/TR/2012/WD-prov-constraints-20120911/">http://www.w3.org/TR/2012/WD-prov-constraints-20120911/</a> <a href="diff-c.html">(colored-coded diff)</a></dd>
+ <dd><a href="http://www.w3.org/TR/2012/WD-prov-constraints-20120911/">http://www.w3.org/TR/2012/WD-prov-constraints-20120911/</a> <a href="diff-c.html">(color-coded diff)</a></dd>
<dt>Editors:</dt>
--- a/model/releases/CR-prov-dm-20121211/Overview.html Fri Dec 07 14:16:58 2012 +0000
+++ b/model/releases/CR-prov-dm-20121211/Overview.html Fri Dec 07 16:58:35 2012 +0000
@@ -793,7 +793,7 @@
<dt>Previous version:</dt>
- <dd><a href="http://www.w3.org/TR/2012/WD-prov-dm-20120724/">http://www.w3.org/TR/2012/WD-prov-dm-20120724/</a> <a href="diff.html">(colored-coded diff)</a></dd>
+ <dd><a href="http://www.w3.org/TR/2012/WD-prov-dm-20120724/">http://www.w3.org/TR/2012/WD-prov-dm-20120724/</a> <a href="diff.html">(color-coded diff)</a></dd>
<dt>Editors:</dt>
--- a/model/releases/CR-prov-n-20121211/Overview.html Fri Dec 07 14:16:58 2012 +0000
+++ b/model/releases/CR-prov-n-20121211/Overview.html Fri Dec 07 16:58:35 2012 +0000
@@ -801,7 +801,7 @@
<dt>Previous version:</dt>
- <dd><a href="http://www.w3.org/TR/2012/WD-prov-n-20120724/">http://www.w3.org/TR/2012/WD-prov-n-20120724/</a> <a href="diff-n.html">(colored-coded diff)</a></dd>
+ <dd><a href="http://www.w3.org/TR/2012/WD-prov-n-20120724/">http://www.w3.org/TR/2012/WD-prov-n-20120724/</a> <a href="diff-n.html">(color-coded diff)</a></dd>
<dt>Editors:</dt>
@@ -2966,7 +2966,7 @@
<p>The Internet Media Type / MIME Type for PROV-N is "text/provenance-notation".</p>
<p>It is recommended that PROV-N files have the extension ".provn" (all lowercase) on all platforms.</p>
<p>It is recommended that PROV-N files stored on Macintosh HFS file systems be given a file type of "TEXT".</p>
- <p>The information that follows has been <a href="https://lists.w3.org/Archives/Member/w3c-archive/2012Nov/0317.html">submitted to the IESG</a> for review, approval, and registration with IANA.</p>
+ <p>The information that follows has been <a href="https://tools.iana.org/public-view/viewticket/642791">submitted to the IESG</a> for review, approval, and registration with IANA.</p>
<dl>
<dt>Type name:</dt>
<dd>text</dd>
--- a/model/prov-magic.js Fri Dec 07 14:16:58 2012 +0000
+++ b/model/prov-magic.js Fri Dec 07 16:58:35 2012 +0000
@@ -14,7 +14,7 @@
})
}
/* A function to add a link to colored-coded diffs next to previous version URI */
function setColoredDiffs () {
setColoredDiffsForFile('diff.html');
}
@@ -24,7 +24,7 @@
var content=$(this).text();
if (content== "Previous version:") {
console.log( "content " + content);
- $(this).next().append(" ").append($('<a>').attr('href',diff_file).append("(colored-coded diff)"));
+ $(this).next().append(" ").append($('<a>').attr('href',diff_file).append("(color-coded diff)"));
}
})
}
@@ -14,7 +14,7 @@
})
}
-/* A function to add a link to colored-coded diffs next to previous version URI */
+/* A function to add a link to color-coded diffs next to previous version URI */
function setColoredDiffs () {
setColoredDiffsForFile('diff.html');